==> jc-1.4.0.tar.gz: java/rmi/dgc/VMID.h <==
// public final class java.rmi.dgc.VMID

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8b185191e4bf911a java_rmi_dgc_VMID

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_dgc_VMID_H_
#define _JC_java_rmi_dgc_VMID_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_rmi_server_UID$object;

// Typedefs
typedef struct _jc_java_rmi_dgc_VMID$sub_refs	_jc_java_rmi_dgc_VMID$sub_refs;
typedef struct _jc_java_rmi_dgc_VMID$sub_nonrefs	_jc_java_rmi_dgc_VMID$sub_nonrefs;
typedef struct _jc_java_rmi_dgc_VMID$refs	_jc_java_rmi_dgc_VMID$refs;
typedef struct _jc_java_rmi_dgc_VMID$nonrefs	_jc_java_rmi_dgc_VMID$nonrefs;
typedef struct _jc_java_rmi_dgc_VMID$object	_jc_java_rmi_dgc_VMID$object;

typedef struct _jc_java_rmi_dgc_VMID$fields_struct	_jc_java_rmi_dgc_VMID$fields_struct;
typedef const struct _jc_java_rmi_dgc_VMID$vmethods	_jc_java_rmi_dgc_VMID$vmethods;
typedef const struct _jc_java_rmi_dgc_VMID$vtable	_jc_java_rmi_dgc_VMID$vtable;
typedef const struct _jc_java_rmi_dgc_VMID$vtype	_jc_java_rmi_dgc_VMID$vtype;

// Class fields structure
struct _jc_java_rmi_dgc_VMID$fields_struct {
	_jc_byte_array	*localAddr;
	jlong	serialVersionUID;
	jboolean	areWeUnique;
};
extern _jc_java_rmi_dgc_VMID$fields_struct _jc_java_rmi_dgc_VMID$class_fields;

// Constructors
extern void _jc_java_rmi_dgc_VMID$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_dgc_VMID$object *);

// Virtual methods
extern jboolean _jc_java_rmi_dgc_VMID$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_rmi_dgc_VMID$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_rmi_dgc_VMID$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_rmi_dgc_VMID$object *);
extern struct _jc_java_lang_String$object *_jc_java_rmi_dgc_VMID$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_rmi_dgc_VMID$object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_dgc_VMID$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_rmi_dgc_VMID$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_rmi_dgc_VMID$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_rmi_dgc_VMID$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern jboolean _jc_java_rmi_dgc_VMID$method$isUnique$e9601c3ac09cbeee(_jc_env *);

// Virtual methods structure
struct _jc_java_rmi_dgc_VMID$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_rmi_dgc_VMID$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_rmi_dgc_VMID$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_rmi_dgc_VMID$object *);
};

// Vtable
struct _jc_java_rmi_dgc_VMID$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_dgc_VMID$vmethods	java_rmi_dgc_VMID;
};

// Vtype
struct _jc_java_rmi_dgc_VMID$vtype {
	_jc_type			type;
	_jc_java_rmi_dgc_VMID$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_dgc_VMID$sub_refs {
	_jc_byte_array	*addr;
	struct _jc_java_rmi_server_UID$object	*uid;
};

// Reference instance fields (object)
struct _jc_java_rmi_dgc_VMID$refs {
    _jc_java_rmi_dgc_VMID$sub_refs	java_rmi_dgc_VMID;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_dgc_VMID$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_dgc_VMID$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_dgc_VMID$sub_nonrefs	java_rmi_dgc_VMID;
};

// Object instance structure
struct _jc_java_rmi_dgc_VMID$object {
	_jc_java_rmi_dgc_VMID$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_dgc_VMID$vtype	*vtype;
	_jc_java_rmi_dgc_VMID$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_dgc_VMID$vtype _jc_java_rmi_dgc_VMID$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_dgc_VMID, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_dgc_VMID$class_object;

#endif	/* _JC_java_rmi_dgc_VMID_H_ */

==> jc-1.4.6.tar.gz: java/rmi/dgc/VMID.h <==
// public final class java.rmi.dgc.VMID

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8b185191e4bf911a java_rmi_dgc_VMID

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_dgc_VMID_H_
#define _JC_java_rmi_dgc_VMID_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_rmi_server_UID$object;

// Typedefs
typedef struct _jc_java_rmi_dgc_VMID$sub_refs	_jc_java_rmi_dgc_VMID$sub_refs;
typedef struct _jc_java_rmi_dgc_VMID$sub_nonrefs	_jc_java_rmi_dgc_VMID$sub_nonrefs;
typedef struct _jc_java_rmi_dgc_VMID$refs	_jc_java_rmi_dgc_VMID$refs;
typedef struct _jc_java_rmi_dgc_VMID$nonrefs	_jc_java_rmi_dgc_VMID$nonrefs;
typedef struct _jc_java_rmi_dgc_VMID$object	_jc_java_rmi_dgc_VMID$object;

typedef struct _jc_java_rmi_dgc_VMID$fields_struct	_jc_java_rmi_dgc_VMID$fields_struct;
typedef const struct _jc_java_rmi_dgc_VMID$vmethods	_jc_java_rmi_dgc_VMID$vmethods;
typedef const struct _jc_java_rmi_dgc_VMID$vtable	_jc_java_rmi_dgc_VMID$vtable;
typedef const struct _jc_java_rmi_dgc_VMID$vtype	_jc_java_rmi_dgc_VMID$vtype;

// Class fields structure
struct _jc_java_rmi_dgc_VMID$fields_struct {
	_jc_byte_array	*localAddr;
	jlong	serialVersionUID;
	jboolean	areWeUnique;
};
extern _jc_java_rmi_dgc_VMID$fields_struct _jc_java_rmi_dgc_VMID$class_fields;

// Constructors
extern void _jc_java_rmi_dgc_VMID$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_dgc_VMID$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_rmi_dgc_VMID$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_rmi_dgc_VMID$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_rmi_dgc_VMID$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_rmi_dgc_VMID$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_rmi_dgc_VMID$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_rmi_dgc_VMID$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_dgc_VMID$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_rmi_dgc_VMID$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_rmi_dgc_VMID$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_rmi_dgc_VMID$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern jboolean _jc_java_rmi_dgc_VMID$method$isUnique$e9601c3ac09cbeee(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_dgc_VMID$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_rmi_dgc_VMID$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_rmi_dgc_VMID$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_rmi_dgc_VMID$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_dgc_VMID$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_dgc_VMID$vmethods	java_rmi_dgc_VMID;
};

// Vtype
struct _jc_java_rmi_dgc_VMID$vtype {
	_jc_type			type;
	_jc_java_rmi_dgc_VMID$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_dgc_VMID$sub_refs {
	_jc_byte_array	*addr;
	struct _jc_java_rmi_server_UID$object	*uid;
};

// Reference instance fields (object)
struct _jc_java_rmi_dgc_VMID$refs {
    _jc_java_rmi_dgc_VMID$sub_refs	java_rmi_dgc_VMID;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_dgc_VMID$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_dgc_VMID$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_dgc_VMID$sub_nonrefs	java_rmi_dgc_VMID;
};

// Object instance structure
struct _jc_java_rmi_dgc_VMID$object {
	_jc_java_rmi_dgc_VMID$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_dgc_VMID$vtype	*vtype;
	_jc_java_rmi_dgc_VMID$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_dgc_VMID$vtype _jc_java_rmi_dgc_VMID$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_dgc_VMID, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_dgc_VMID$class_object;

#endif	/* _JC_java_rmi_dgc_VMID_H_ */
